import pandas as pd
from pandas_datareader import data
import datetime
import csv
import matplotlib.pyplot as plt
import qqpat

def lastValue(x):
    try:
        reply = x[-1]
    except:
        reply = None
    return reply
    
system_list = ["sys0"]

for index, system in enumerate(system_list):
    tradeTimes = []
    tradeBalance = []
    with open(system + ".txt", 'rb') as csvfile:
        reader = csv.reader(csvfile)
        for idx_data, row in enumerate(reader):
            if idx_data > 0:
                tradeTimes.append(datetime.datetime.strptime(row[3], '%d/%m/%Y %H:%M'))
                tradeBalance.append(float(row[10]))      
        if index == 0:
            data = pd.Series(data=tradeBalance, index=tradeTimes).resample('D', how=lastValue).pct_change(fill_method='pad').fillna(0)
        else:
            data = pd.concat([data, pd.Series(data=tradeBalance, index=tradeTimes).resample('D', how=lastValue).pct_change(fill_method='pad').fillna(0)], axis=1)
            
data = data.fillna(0.0)
                                     
analyzer = qqpat.Analizer(data, column_type='return', titles=system_list)
long_term_sharpe = analyzer.get_sharpe_ratio()[0]
long_term_cagr = analyzer.get_cagr()[0]
print long_term_sharpe
print long_term_cagr
sharpes90 = []
sharpes80 = []
sharpes70 = []
sharpes60 = []
cagr90 = []
cagr80 = []
cagr70 = []
cagr60 = []
periods = range(100,1000,100)

for i in periods:
    stats = analyzer.get_mc_statistics(index=0, iterations=1000, confidence=90, period_length=i)
    sharpes90.append(stats['wc_sharpe'])
    cagr90.append(stats['wc_cagr'])
    stats = analyzer.get_mc_statistics(index=0, iterations=1000, confidence=80, period_length=i)
    sharpes80.append(stats['wc_sharpe']) 
    cagr80.append(stats['wc_cagr'])
    stats = analyzer.get_mc_statistics(index=0, iterations=1000, confidence=70, period_length=i)
    sharpes70.append(stats['wc_sharpe'])  
    cagr70.append(stats['wc_cagr'])
    stats = analyzer.get_mc_statistics(index=0, iterations=1000, confidence=60, period_length=i)
    sharpes60.append(stats['wc_sharpe'])
    cagr60.append(stats['wc_cagr'])
    print i

fig, ax = plt.subplots(figsize=(12,8), dpi=100)
ax.set_xlabel('Period length (days)')
ax.set_ylabel('Sharpe') 
ax.plot(periods, sharpes90)
ax.plot(periods, sharpes80)
ax.plot(periods, sharpes70)
ax.plot(periods, sharpes60)
ax.axhline(long_term_sharpe, linestyle='dashed', color='black', linewidth=1.5)
plt.show()

fig, ax = plt.subplots(figsize=(12,8), dpi=100)
ax.set_xlabel('Period length (days)')
ax.set_ylabel('CAGR (%)') 
ax.plot(periods, cagr90)
ax.plot(periods, cagr80)
ax.plot(periods, cagr70)
ax.plot(periods, cagr60)
ax.axhline(long_term_cagr, linestyle='dashed', color='black', linewidth=1.5)
plt.show()
 




